@@ -678,7 +678,7 @@ class EscriptoriumConnector:
             as_form_data=True,
         )
 
-        message = ws.recv(30)
+        message = ws.recv(120)
         ws.close()
         logging.debug(message)
         msg = json.loads(message)
@@ -792,7 +792,7 @@ class EscriptoriumConnector:
             List[PostMoveLine]
         )
 
-    def bulk_update_lines(self, doc_pk: int, park_pk: int, lines:list[GetLine], fields: List[str]) -> List[GetLine]:
+    def bulk_update_lines(self, doc_pk: int, park_pk: int, lines:List[GetLine], fields: List[str]) -> List[GetLine]:
         if 'pk' not in fields:
             fields.append('pk')
 
